@@ -4,7 +4,7 @@ import os
 import platform
 import stat
 from pathlib import Path
-from typing import Optional
+from typing import Dict, List, Optional
 
 import requests
 from packaging import version
@@ -27,12 +27,6 @@ from RPA.core.robocorp import robocorp_home
 LOGGER = logging.getLogger(__name__)
 
 DRIVER_ROOT = robocorp_home() / "webdrivers"
-DRIVER_PREFERENCE = {
-    "Windows": ["Chrome", "Firefox", "ChromiumEdge"],
-    "Linux": ["Chrome", "Firefox", "ChromiumEdge"],
-    "Darwin": ["Chrome", "Firefox", "ChromiumEdge", "Safari"],
-    "default": ["Chrome", "Firefox"],
-}
 AVAILABLE_DRIVERS = {
     # Driver names taken from `webdrivermanager` and adapted to `webdriver_manager`.
     "chrome": ChromeDriverManager,
@@ -48,6 +42,47 @@ AVAILABLE_DRIVERS = {
     # NOTE: IE is discontinued and not supported/encouraged anymore.
     "ie": IEDriverManager,
 }
+_DRIVER_PREFERENCE = {
+    "Windows": ["Chrome", "Firefox", "ChromiumEdge"],
+    "Linux": ["Chrome", "Firefox", "ChromiumEdge"],
+    "Darwin": ["Chrome", "Firefox", "ChromiumEdge", "Safari"],
+    "default": ["Chrome", "Firefox"],
+}
+
+
+def _get_browser_order_from_env() -> Optional[List[str]]:
+    browsers: str = os.getenv("RPA_SELENIUM_BROWSER_ORDER", "")
+    if browsers:
+        return [browser.strip() for browser in browsers.split(sep=",")]
+
+    return None  # meaning there's no env var to control the order
+
+
+def get_browser_order() -> List[str]:
+    """Get a list of preferred browsers based on the environment variable
+    `RPA_SELENIUM_BROWSER_ORDER` if set.
+
+    The OS dictates the order if no such env var is set.
+    """
+    browsers: Optional[List[str]] = _get_browser_order_from_env()
+    if browsers:
+        return browsers
+
+    return _DRIVER_PREFERENCE.get(platform.system(), _DRIVER_PREFERENCE["default"])
+
+
+def _set_driver_preference() -> Dict[str, List[str]]:
+    pref = _DRIVER_PREFERENCE.copy()
+    browsers: Optional[List[str]] = _get_browser_order_from_env()
+    if browsers:
+        for op_sys in pref:
+            pref[op_sys] = browsers
+    return pref
+
+
+# FIXME(cmin764): This constant is deprecated and is planned for removal in the next
+#  major upgrade. (use `get_browser_order` function instead)
+DRIVER_PREFERENCE = _set_driver_preference()
 
 
 class Downloader(WDMHttpClient):
@@ -129,7 +164,7 @@ def download(browser: str, root: Path = DRIVER_ROOT) -> Optional[str]:
     driver = manager.driver
     resolved_os = getattr(driver, "os_type", driver.get_os_type())
     os_name = get_os_name()
-    if os_name not in resolved_os:
+    if os_name.lower() not in resolved_os.lower():
         LOGGER.warning(
             "Attempting to download incompatible driver for OS %r on OS %r! Skip",
             resolved_os,
